@@ -15,11 +15,11 @@ func NewLogDoc() (*Document, error) {
 	m.FollowMode = true
 	m.Caption = "Log"
 	m.seekable = false
-	log.SetOutput(m)
 	atomic.StoreInt32(&m.closed, 1)
 	if err := m.ControlLog(); err != nil {
 		return nil, err
 	}
+	log.SetOutput(m)
 	return m, nil
 }
 
@@ -27,7 +27,7 @@ func NewLogDoc() (*Document, error) {
 // Therefore, the log.Print output is displayed by logDoc.
 func (m *Document) Write(p []byte) (int, error) {
 	chunk := m.chunkForAdd()
-	m.append(chunk, p)
+	m.appendLine(chunk, p)
 	if len(chunk.lines) >= ChunkSize {
 		chunk = NewChunk(m.size)
 		m.mu.Lock()
