@@ -77,6 +77,7 @@ func (root *Root) wheelRight() {
 		root.moveRightN(4)
 	}
 }
+
 func (root *Root) wheelLeft() {
 	root.setMessage("")
 	if root.Doc.ColumnMode {
@@ -144,69 +145,22 @@ func (root *Root) CopySelect() {
 	root.postEvent(ev)
 }
 
-// drawSelect highlights the selection.
-// Multi-line selection is included until the end of the line,
-// but if the rectangle flag is true, the rectangle will be the range.
-func (root *Root) drawSelect(x1, y1, x2, y2 int, sel bool) {
+// putClipboard writes the selection to the clipboard.
+func (root *Root) putClipboard(_ context.Context) {
+	x1 := root.x1
+	x2 := root.x2
+	y1 := root.y1
+	y2 := root.y2
+
+	if y2 < y1 {
+		y1, y2 = y2, y1
+		x1, x2 = x2, x1
+	}
 	if y1 == y2 {
 		if x2 < x1 {
 			x1, x2 = x2, x1
 		}
-		root.reverseLine(y1, x1, x2+1, sel)
-		return
 	}
-
-	if y2 < y1 {
-		y1, y2 = y2, y1
-		x1, x2 = x2, x1
-	}
-
-	if root.mouseRectangle {
-		root.drawRectangle(x1, y1, x2, y2, sel)
-		return
-	}
-
-	root.reverseLine(y1, x1, root.vWidth, sel)
-	for y := y1 + 1; y < y2; y++ {
-		root.reverseLine(y, 0, root.vWidth, sel)
-	}
-	root.reverseLine(y2, 0, x2+1, sel)
-}
-
-// drawRectangle highlights the rectangular area.
-func (root *Root) drawRectangle(x1, y1, x2, y2 int, sel bool) {
-	for y := y1; y <= y2; y++ {
-		root.reverseLine(y, x1, x2+1, sel)
-	}
-}
-
-// reverseLine reverses one line.
-func (root *Root) reverseLine(y int, start int, end int, sel bool) {
-	if start >= end {
-		return
-	}
-	for x := start; x < end; x++ {
-		mainc, combc, style, width := root.Screen.GetContent(x, y)
-		style = style.Reverse(sel)
-		root.Screen.SetContent(x, y, mainc, combc, style)
-		if width == 2 {
-			x++
-		}
-	}
-}
-
-// putClipboard writes the selection to the clipboard.
-func (root *Root) putClipboard(_ context.Context) {
-	y1 := root.y1
-	y2 := root.y2
-	x1 := root.x1
-	x2 := root.x2
-
-	if y2 < y1 {
-		y1, y2 = y2, y1
-		x1, x2 = x2, x1
-	}
-
 	buff, err := root.rangeToString(x1, y1, x2, y2)
 	if err != nil {
 		root.debugMessage(fmt.Sprintf("putClipboard: %s", err.Error()))
@@ -222,140 +176,6 @@ func (root *Root) putClipboard(_ context.Context) {
 	root.setMessage("Copy")
 }
 
-// rangeToString returns the selection.
-func (root *Root) rangeToString(x1, y1, x2, y2 int) (string, error) {
-	if root.mouseRectangle {
-		return root.rectangleToString(x1, y1, x2, y2)
-	}
-
-	var buff strings.Builder
-
-	l1 := root.lineInfo(y1)
-	lc1, err := root.Doc.contentsLN(l1.number, root.Doc.TabWidth)
-	if err != nil {
-		return "", err
-	}
-	wx1 := root.branchWidth(lc1, l1.wrap)
-
-	l2 := root.lineInfo(y2)
-	lc2, err := root.Doc.contentsLN(l2.number, root.Doc.TabWidth)
-	if err != nil {
-		return "", err
-	}
-	wx2 := root.branchWidth(lc2, l2.wrap)
-
-	if l1.number == l2.number {
-		str := root.selectLine(l1.number, root.Doc.x+x1+wx1, root.Doc.x+x2+wx2+1)
-		if len(str) == 0 {
-			return buff.String(), nil
-		}
-		if _, err := buff.WriteString(str); err != nil {
-			return "", err
-		}
-		return buff.String(), nil
-	}
-
-	first := root.selectLine(l1.number, root.Doc.x+x1+wx1, -1)
-	if _, err := buff.WriteString(first); err != nil {
-		return "", err
-	}
-	if err := buff.WriteByte('\n'); err != nil {
-		return "", err
-	}
-
-	for y := y1 + 1; y < y2; y++ {
-		l := root.lineInfo(y)
-		if l.number == l1.number || l.number == l2.number || l.wrap > 0 {
-			continue
-		}
-		str := root.selectLine(l.number, 0, -1)
-		if _, err := buff.WriteString(str); err != nil {
-			return "", err
-		}
-		if err := buff.WriteByte('\n'); err != nil {
-			return "", err
-		}
-	}
-
-	last := root.selectLine(l2.number, 0, root.Doc.x+x2+wx2+1)
-	if _, err := buff.WriteString(last); err != nil {
-		return "", err
-	}
-
-	return buff.String(), nil
-}
-
-// rectangleToByte returns a rectangular range.
-func (root *Root) rectangleToString(x1, y1, x2, y2 int) (string, error) {
-	var buff strings.Builder
-
-	for y := y1; y <= y2; y++ {
-		ln := root.lineInfo(y)
-		lc, err := root.Doc.contentsLN(ln.number, root.Doc.TabWidth)
-		if err != nil {
-			return "", err
-		}
-		wx := root.branchWidth(lc, ln.wrap)
-		str := root.selectLine(ln.number, root.Doc.x+x1+wx, root.Doc.x+x2+wx+1)
-
-		if _, err := buff.WriteString(str); err != nil {
-			return "", err
-		}
-		if err := buff.WriteByte('\n'); err != nil {
-			return "", err
-		}
-	}
-	return buff.String(), nil
-}
-
-// branchWidth returns the leftmost position of the number of wrapped line.
-func (root *Root) branchWidth(lc contents, branch int) int {
-	i := 0
-	w := root.startX
-	x := 0
-	for n := 0; n < len(lc); n++ {
-		c := lc[n]
-		if w+c.width > root.vWidth {
-			i++
-			w = root.startX
-		}
-		if i >= branch {
-			break
-		}
-		w += c.width
-		x += c.width
-	}
-	return x
-}
-
-// selectLine returns a string in the specified range on one line.
-func (root *Root) selectLine(ly int, x1 int, x2 int) string {
-	lc, err := root.Doc.contentsLN(ly, root.Doc.TabWidth)
-	if err != nil {
-		root.debugMessage(fmt.Sprintf("%s", err))
-		return ""
-	}
-
-	size := len(lc)
-	// -1 is a special max value.
-	if x2 == -1 {
-		x2 = size
-	}
-
-	x1 -= root.startX
-	x2 -= root.startX
-	x1 = max(0, x1)
-	x2 = max(0, x2)
-	x1 = min(x1, size)
-	x2 = min(x2, size)
-	if x1 > x2 {
-		x1, x2 = x2, x1
-	}
-
-	str, _ := ContentsToStr(lc[x1:x2])
-	return str
-}
-
 type eventPaste struct {
 	tcell.EventTime
 }
@@ -391,3 +211,202 @@ func (root *Root) getClipboard(_ context.Context) {
 	input.value += string(runes[pos:])
 	input.cursorX += runewidth.StringWidth(str)
 }
+
+// drawSelect highlights the selection.
+// Multi-line selection is included until the end of the line,
+// but if the rectangle flag is true, the rectangle will be the range.
+func (root *Root) drawSelect(x1, y1, x2, y2 int, sel bool) {
+	if y2 < y1 {
+		y1, y2 = y2, y1
+		x1, x2 = x2, x1
+	}
+	if y1 == y2 {
+		if x2 < x1 {
+			x1, x2 = x2, x1
+		}
+		root.reverseLine(y1, x1, x2+1, sel)
+		return
+	}
+	if root.mouseRectangle {
+		for y := y1; y <= y2; y++ {
+			root.reverseLine(y, x1, x2+1, sel)
+		}
+		return
+	}
+
+	root.reverseLine(y1, x1, root.scr.vWidth, sel)
+	for y := y1 + 1; y < y2; y++ {
+		root.reverseLine(y, 0, root.scr.vWidth, sel)
+	}
+	root.reverseLine(y2, 0, x2+1, sel)
+}
+
+// reverseLine reverses one line.
+func (root *Root) reverseLine(y int, start int, end int, sel bool) {
+	if start >= end {
+		return
+	}
+	for x := start; x < end; x++ {
+		mainc, combc, style, width := root.Screen.GetContent(x, y)
+		style = style.Reverse(sel)
+		root.Screen.SetContent(x, y, mainc, combc, style)
+		if width == 2 {
+			x++
+		}
+	}
+}
+
+func (root *Root) rangeToString(x1, y1, x2, y2 int) (string, error) {
+	if root.mouseRectangle {
+		return root.scr.rectangleToString(root.Doc, x1, y1, x2, y2)
+	}
+	return root.scr.lineRangeToString(root.Doc, x1, y1, x2, y2)
+}
+
+// lineRangeToString returns the selection.
+// The arguments must be x1 <= x2 and y1 <= y2.
+// ...◼◻◻◻◻◻
+// ◻◻◻◻◻◻◻◻
+// ◻◻◻◼......
+func (scr SCR) lineRangeToString(m *Document, x1, y1, x2, y2 int) (string, error) {
+	var buff strings.Builder
+
+	l1 := scr.lineNumber(y1)
+	line1, valid := m.getLineC(l1.number, m.TabWidth)
+	if !valid {
+		return "", ErrOutOfRange
+	}
+	wx1 := scr.branchWidth(line1.lc, l1.wrap)
+
+	var l2 LineNumber
+	for y := y2; ; y-- {
+		l := scr.lineNumber(y)
+		if l.number < m.BufEndNum() {
+			l2 = l
+			y2 = y
+			break
+		}
+	}
+	line2, valid := m.getLineC(l2.number, m.TabWidth)
+	if !valid {
+		return "", ErrOutOfRange
+	}
+	wx2 := scr.branchWidth(line2.lc, l2.wrap)
+
+	if l1.number == l2.number {
+		x1 := m.x + x1 + wx1
+		x2 := m.x + x2 + wx2
+		str := scr.selectLine(line1, x1, x2+1)
+		if len(str) == 0 {
+			return buff.String(), nil
+		}
+		if _, err := buff.WriteString(str); err != nil {
+			return "", fmt.Errorf("lineRangeToString: %w", err)
+		}
+
+		return buff.String(), nil
+	}
+
+	first := scr.selectLine(line1, m.x+x1+wx1, -1)
+	if _, err := buff.WriteString(first); err != nil {
+		return "", fmt.Errorf("lineRangeToString: %w", err)
+	}
+	if err := buff.WriteByte('\n'); err != nil {
+		return "", fmt.Errorf("lineRangeToString: %w", err)
+	}
+
+	for y := y1 + 1; y < y2; y++ {
+		ln := scr.lineNumber(y)
+		if ln.number == l1.number || ln.number == l2.number || ln.wrap > 0 {
+			continue
+		}
+		line, valid := m.getLineC(ln.number, m.TabWidth)
+		if !valid {
+			break
+		}
+		str := scr.selectLine(line, 0, -1)
+		if _, err := buff.WriteString(str); err != nil {
+			return "", fmt.Errorf("lineRangeToString: %w", err)
+		}
+		if err := buff.WriteByte('\n'); err != nil {
+			return "", fmt.Errorf("lineRangeToString: %w", err)
+		}
+	}
+
+	last := scr.selectLine(line2, 0, m.x+x2+wx2+1)
+	if _, err := buff.WriteString(last); err != nil {
+		return "", fmt.Errorf("lineRangeToString: %w", err)
+	}
+
+	return buff.String(), nil
+}
+
+// rectangleToByte returns a rectangular range.
+// The arguments must be x1 <= x2 and y1 <= y2.
+// ...◼◻◻...
+// ...◻◻◻...
+// ...◻◻◼...
+func (scr SCR) rectangleToString(m *Document, x1, y1, x2, y2 int) (string, error) {
+	var buff strings.Builder
+	for y := y1; y <= y2; y++ {
+		ln := scr.lineNumber(y)
+		line, valid := m.getLineC(ln.number, m.TabWidth)
+		if !valid {
+			return "", fmt.Errorf("rectangleToString: %w", ErrOutOfRange)
+		}
+		wx := scr.branchWidth(line.lc, ln.wrap)
+		str := scr.selectLine(line, m.x+x1+wx, m.x+x2+wx+1)
+		if _, err := buff.WriteString(str); err != nil {
+			return "", fmt.Errorf("rectangleToString: %w", err)
+		}
+		if err := buff.WriteByte('\n'); err != nil {
+			return "", fmt.Errorf("rectangleToString: %w", err)
+		}
+	}
+	return buff.String(), nil
+}
+
+// branchWidth returns the leftmost position of the number of wrapped line.
+// If the wide character is at the right end, it may wrap one character forward.
+func (scr SCR) branchWidth(lc contents, branch int) int {
+	i := 0
+	w := scr.startX
+	x := 0
+	for n := 0; n < len(lc); n++ {
+		c := lc[n]
+		if w+c.width > scr.vWidth {
+			i++
+			w = scr.startX
+		}
+		if i >= branch {
+			break
+		}
+		w += c.width
+		x += c.width
+	}
+	return x
+}
+
+// selectLine returns a string in the specified range on one line.
+// The arguments must be x1 <= x2.
+func (scr SCR) selectLine(line LineC, x1 int, x2 int) string {
+	maxX := len(line.lc)
+	// -1 is a special max value.
+	if x2 == -1 {
+		x2 = maxX
+	}
+	x1 -= scr.startX
+	x2 -= scr.startX
+	x1 = max(0, x1)
+	x2 = max(0, x2)
+	x1 = min(x1, maxX)
+	x2 = min(x2, maxX)
+	start := line.pos.n(x1)
+	end := line.pos.n(x2)
+
+	if start > len(line.str) || end > len(line.str) {
+		log.Printf("selectLine:len(%d):start(%d):end(%d)", len(line.str), start, end)
+		return ""
+	}
+	return line.str[start:end]
+}
